<?php

namespace ACL\Controllers;

use ACL\Traits\TResponse;
use Exception;
use Zeedhi\Framework\DTO\Request;
use ACL\Services\Opergrupop as OpergrupopService;

class Opergrupop
{

    use TResponse;

    /**
     * @var OpergrupopService
     */
    private $opergrupopService;

    public function __construct(OpergrupopService $opergrupopService)
    {
        $this->opergrupopService = $opergrupopService;
    }

    /**
     * @param Request $request
     * @throws Exception
     */
    public function findOpergrupopByOperador(Request $request)
    {
        try{
            $params = $request->getParameters();
            $cdoperador = !empty($params['CDOPERADOR']) ? $params['CDOPERADOR'] : null;
            $sqlOperator = !empty($params['SQL_OPERATOR']) ? $params['SQL_OPERATOR'] : 'IN';
            $data = $this->opergrupopService->findOpergrupopByOperador($cdoperador, $sqlOperator);
            $this->sendResponse($data, 200);
        }catch(Exception $ex){
            $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
        }
    }

    /**
     * @param Request $request
     * @throws \Doctrine\DBAL\Driver\Exception
     * @throws Exception
     */
    public function createOpergrupop(Request $request)
    {
        try{
            $params = $request->getParameters();
            $labels = $params[0]['aclNextLabelsTraductionLog'][0];
            $this->opergrupopService->createOpergrupop($params, $labels);
            $this->sendResponse([], 201);
        }catch(Exception $ex){
            $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
        }
    }

    /**
     * @param Request $request
     * @throws \Doctrine\DBAL\Driver\Exception
     * @throws Exception
     */
    public function updateOpergrupop(Request $request)
    {
        try{
            $params = $request->getParameters();
            $labels = $params['aclNextLabelsTraductionLog'][0];
            $cdgrupoper = $params['CDGRUPOPER'];
            $cdoperador = $params['CDOPERADOR'];
            $idmenuprinop = $params['IDMENUPRINOP'];
            $this->opergrupopService->updateOpergrupop($cdgrupoper, $cdoperador, $idmenuprinop, $labels);
            $this->sendResponse(null, 204);
        }catch(Exception $ex){
            $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
        }
    }

    /**
     * @param Request $request
     * @throws \Doctrine\DBAL\Driver\Exception
     * @throws Exception
     */
    public function deleteOpergrupop(Request $request)
    {
        try{
            $params = $request->getParameters();
            $labels = $params[0]['aclNextLabelsTraductionLog'][0];
            $this->opergrupopService->deleteOpergrupop($params, $labels);
            $this->sendResponse(null, 204);
        }catch(Exception $ex){
            $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
        }
    }
}
