<?php

namespace ACL\Repositories;

use ACL\Traits\TQuery;
use ACL\Helpers\Instances\InstanceProvider;
use Doctrine\DBAL\Exception;
use Doctrine\ORM\EntityManager;

class OperadorLabelVersao extends RepositoryBase {

    Use TQuery;

    protected $table = 'OPERADOR_LABEL_VERSAO';

    /** @var EntityManager */
    protected $entityManager;

    public function __construct(EntityManager $entityManager)
    {
        parent::__construct($this->table);
        $this->entityManager = $entityManager;
    }

    /**
     * @throws Exception
     */
    public function findByOperadorAndProject($productId, $cdoperador, $nrorg): array
    {
        $query = <<<SQL
            SELECT ID, PRODUCT_ID, CDOPERADOR, NRULTVERSAO
              FROM OPERADOR_LABEL_VERSAO
             WHERE PRODUCT_ID = :PRODUCT_ID
               AND CDOPERADOR = :CDOPERADOR
               AND NRORG = :NRORG
SQL;
        $params = array(
            'PRODUCT_ID' => $productId,
            "CDOPERADOR" => $cdoperador,
            "NRORG" => $nrorg
        );
        return $this->entityManager->getConnection()->fetchAllAssociative($query, $params);
    }

    /**
     * @param $id
     * @param $productId
     * @param $cdoperador
     * @param $nrultVersao
     * @param $nrorg
     * @param $idativo
     * @param $cdoperinclusao
     * @return void
     * @throws Exception
     * @throws \Doctrine\DBAL\Driver\Exception
     */
    public function createByOperadorAndProject($id, $productId, $cdoperador, $nrultVersao, $nrorg, $idativo, $cdoperinclusao)
    {
        $query = "INSERT INTO OPERADOR_LABEL_VERSAO
                              (ID, PRODUCT_ID, CDOPERADOR, NRULTVERSAO, NRORG, IDATIVO, DTINCLUSAO, NRORGINCLUSAO, CDOPERINCLUSAO)
                       VALUES (:ID, :PRODUCT_ID, :CDOPERADOR, :NRULTVERSAO, :NRORG, :IDATIVO, SYSDATE, :NRORG, :CDOPERINCLUSAO)";

        $params = array(
            'ID' => $id,
            'PRODUCT_ID' => $productId,
            'CDOPERADOR' => $cdoperador,
            'NRULTVERSAO' => $nrultVersao,
            'NRORG' => $nrorg,
            "IDATIVO" => $idativo,
            "CDOPERINCLUSAO" => $cdoperinclusao,
        );

        try {
            $std = $this->entityManager->getConnection()->prepare($query);
            $std->executeQuery($params);
        } catch (\Doctrine\DBAL\Driver\Exception $e) {
            throw new $e;
        }
    }

    public function updateVersion($id, $nrultVersao, $nrorg, $cdoperinclusao)
    {
        $query = "UPDATE OPERADOR_LABEL_VERSAO
                     SET NRULTVERSAO = :NRULTVERSAO,
                            DTULTATU =  SYSDATE,
                         NRORGULTATU = :NRORG,
                        CDOPERULTATU = :CDOPERULTATU
                   WHERE ID = :ID
                     AND NRORG = :NRORG ";

        $params = array(
            'ID' => $id,
            'NRULTVERSAO' => $nrultVersao,
            'NRORG' => $nrorg,
            "CDOPERULTATU" => $cdoperinclusao,
        );

        try {
            $std = $this->entityManager->getConnection()->prepare($query);
            $std->executeQuery($params);
        } catch (\Doctrine\DBAL\Driver\Exception $e) {
            throw new $e;
        }
    }
}
