import { Http, Loader, Metadata, Singleton } from '@zeedhi/core';
import { IGridEvent, LoadingService, Modal, ModalService } from '@zeedhi/common';
import { TekGrid, TekRestDatasource } from '@zeedhi/teknisa-components-common';
import AclMessages from '@/Util/AclMessages';
import { PmLibAlertService, PmLibDialogService, PmLibFormSave, PmLibHttp } from '@zeedhi/pm-lib';
import { PerfilDeAcessoController } from '@/controllers/PerfilDeAcesso/PerfilDeAcessoController';

@Singleton
export class PerfilDeAcessoGridController {
	public perfilDeAcessoControler: PerfilDeAcessoController;

	private _gridTitle: string = '';

	public get gridTitle() {
		return this._gridTitle;
	}

	public set gridTitle(label) {
		this._gridTitle = label;
	}

	public _actionEnablePerfilAcessoLabel: string = '';

	public get actionEnablePerfilAcessoLabel() {
		return this._actionEnablePerfilAcessoLabel;
	}

	public set actionEnablePerfilAcessoLabel(label) {
		this._actionEnablePerfilAcessoLabel = label;
	}

	public get isVisiblePerfildeAcessoGrid() {
		return this.perfilDeAcessoControler.isVisibleGridAndDetail;
	}

	constructor() {
		this.perfilDeAcessoControler = Loader.getInstance('PerfilDeAcessoController');
	}

	public getInstancePerfilAcessoGrid(): TekGrid {
		return Metadata.getInstance<TekGrid>('perfilDeAcessoGrid');
	}

	public getColumnStyle(params: any) {
		return params.row.IDATIVO === 'N' ? 'acl-grid-column-inactive' : '';
	}

	/** Events Methods */

	public async onMountedPerfilDeAcessoGrid() {
		this.gridTitle = 'Teste Edit';
		this.addPerfilDeAcessoModal = await ModalService.createFromJson('components/perfil-de-acesso/grid/modais/addPerfilDeAcesso', true);
		await this.findAccessControlUtilization();
		const grid = this.getInstancePerfilAcessoGrid();
		if (grid.datasource instanceof TekRestDatasource) {
			grid.datasource.dynamicFilter = {
				IDATIVO: [
					{
						operation: 'EQUALS',
						relation: 'AND',
						value: 'S',
					},
				],
			};

			try {
				await grid.datasource.get();
			} catch (e) {
				PmLibDialogService.showErrorBackend(e);
			}
		}
	}

	private async findAccessControlUtilization() {
		const response = await Http.get('/findAccessControlUtilization');
		let idutctrlacesweb: string;

		if (response.data.IDUTCTRLACESWEB) {
			idutctrlacesweb = response.data.IDUTCTRLACESWEB;
		} else {
			idutctrlacesweb = 'N';
		}

		localStorage.setItem('idutctrlacesweb', idutctrlacesweb);
		this.perfilDeAcessoControler.currentCdoperador = response.data.CDOPERADOR;
		this.perfilDeAcessoControler.currentNrorg = response.data.NRORG;
		this.changeLabelEnableAccessProfile(idutctrlacesweb);
	}

	private changeLabelEnableAccessProfile(idutctrlacesweb: string) {
		if (idutctrlacesweb === 'N') {
			this.perfilDeAcessoControler.accesControl = false;
			this.gridTitle = 'Perfil de Acesso (Controle de Acesso Desativado)';
			this.actionEnablePerfilAcessoLabel = 'Ativar controle de acesso';
		} else {
			this.perfilDeAcessoControler.accesControl = true;
			this.gridTitle = 'Perfil de Acesso';
			this.actionEnablePerfilAcessoLabel = 'Desativar controle de acesso';
		}
	}

	public async clickPerfilAcesssoControlAction() {
		const confirm = await PmLibDialogService.confirmDialog(AclMessages.CONFIRM_ACTIVE_PERFIL_ACESSO);
		if (confirm) {
			const idutctrlacesweb = this.perfilDeAcessoControler.accesControl ? 'S' : 'N';
			const dataset = { idutctrlacesweb };
			const response = await PmLibHttp.$post('/access-control', dataset);
			this.changeLabelEnableAccessProfile(response.data.idutctrlacesweb);
		}
	}

	public addClickPerfilDeAcessoGrid() {
		this.addPerfilDeAcessoModal.show();
	}

	public async beforeSavePerfilDeAcessoGrid({ event }: IGridEvent) {
		event?.preventDefault();
		const grid = this.getInstancePerfilAcessoGrid();
		const modifiedItems = grid.getEditedRows();

		try {
			LoadingService.show();
			await Http.put('/perfilacesso', modifiedItems);
			LoadingService.hide();
			PmLibAlertService.showSuccess(AclMessages.SUCCESS_SAVE_DEAFULT);
			await grid.reload();
			await grid.cancelEditedRows();
		} catch (e) {
			LoadingService.hide();
			PmLibDialogService.showErrorBackend(e);
		}
	}

	public async beforeDeletePerfilDeAcessoGrid({ event }: IGridEvent) {
		event?.preventDefault();
		const confirm = await PmLibDialogService.confirmDialog(AclMessages.DELETE_DEFAULT);
		if (confirm) {
			this.deletePerfiDeAcesso();
		}
	}

	private async deletePerfiDeAcesso() {
		try {
			const grid = this.getInstancePerfilAcessoGrid();
			LoadingService.show();
			await Http.delete('/perfilacesso', { data: { rows: grid.selectedRows } });
			LoadingService.hide();
			PmLibAlertService.showSuccess(AclMessages.SUCCESS_DELETE_DEAFULT);
			await grid.reload();
		} catch (e) {
			LoadingService.hide();
			PmLibDialogService.showErrorBackend(e);
		}
	}

	public async cellClickPerfilDeAcessoGrid({ row }: IGridEvent) {
		this.perfilDeAcessoControler.isVisibleGridAndDetail = false;
		this.perfilDeAcessoControler.currentPerfilDeAcesso = row;
		this.perfilDeAcessoControler.changePerfilDeAcessoDetailTabs();
	}

	/** Add Perfil Acesso */

	private addPerfilDeAcessoModal!: Modal;

	public closeAddPerfilDeAcessoModal() {
		this.addPerfilDeAcessoModal.hide();
	}

	public async saveAddPerfilDeAcessoModal() {
		const addForm = Metadata.getInstance<PmLibFormSave>('addPerfilDeAcessoModalForm');
		const grid = this.getInstancePerfilAcessoGrid();

		if (addForm.validate()) {
			try {
				LoadingService.show();
				await Http.post('/perfilacesso', addForm.value);
				LoadingService.hide();
				this.addPerfilDeAcessoModal.hide();
				PmLibAlertService.showSuccess(AclMessages.SUCCESS_SAVE_DEAFULT);
				await grid.reload();
			} catch (e) {
				LoadingService.hide();
				PmLibDialogService.showErrorBackend(e);
			}
		}
	}
}
